@@ -1,5 +1,5 @@
 package vCard::AddressBook;
-$vCard::AddressBook::VERSION = '3.05';
+$vCard::AddressBook::VERSION = '3.08';
 use Moo;
 
 use vCard;
@@ -9,7 +9,7 @@ use Text::vCard::Addressbook;
 
 =head1 NAME
 
-vCard::AddressBook - Read, write, and edit a multiple vCards
+vCard::AddressBook - Read, write, and edit vCard address books
 
 =head1 SYNOPSIS
 
@@ -22,7 +22,7 @@ vCard::AddressBook - Read, write, and edit a multiple vCards
     $address_book->load_file('/path/file.vcf');
     $address_book->load_string($string);
 
-    my $vcard = $adress_book->add_vcard; # returns a vCard object
+    my $vcard = $address_book->add_vcard; # returns a vCard object
     $vcard->full_name('Bruce Banner, PhD');
     $vcard->family_names(['Banner']);
     $vcard->given_names(['Bruce']);
@@ -31,8 +31,8 @@ vCard::AddressBook - Read, write, and edit a multiple vCards
         { type => ['home'], address => 'bbanner@timewarner.com'      },
     ]);
 
-    # $address_book->vcards() returns a list of vCard objects
-    foreach my $vcard ( $address_book->vcards() ) {
+    # $address_book->vcards() returns an arrayref of vCard objects
+    foreach my $vcard (@{ $address_book->vcards() }) {
         print $vcard->full_name() . "\n";
         print $vcard->email_addresses->[0]->{address} . "\n";
     }
